@@ -23,7 +23,7 @@ class FalconWriter(object):
 	def push_falcon_data(self, falconData=None):
 		try:
 			logger.debug("falconUrl: " + self.falconUrl)
-			logger.debug("data: " + falconData)
+			logger.debug("data: " + str(falconData))
 			resp = requests.post(self.falconUrl, json=falconData, headers=self.headers)
 			logger.debug("resp: " + str(resp))
 			if not resp.status_code == 200:
